@@ -123,9 +123,9 @@ bool KCategorizedView::Private::isCategorized() const
     return proxyModel && categoryDrawer && proxyModel->isCategorizedModel();
 }
 
-QStyleOptionViewItemV4 KCategorizedView::Private::blockRect(const QModelIndex &representative)
+QStyleOptionViewItem KCategorizedView::Private::blockRect(const QModelIndex &representative)
 {
-    QStyleOptionViewItemV4 option(q->viewOptions());
+    QStyleOptionViewItem option(q->viewOptions());
     const int height = categoryDrawer->categoryHeight(representative, option);
     const QString categoryDisplay = representative.data(KCategorizedSortFilterProxyModel::CategoryDisplayRole).toString();
     QPoint pos = blockPosition(categoryDisplay);
@@ -798,9 +798,9 @@ void KCategorizedView::paintEvent(QPaintEvent *event)
     while (it != d->blocks.constEnd()) {
         const Private::Block &block = *it;
         const QModelIndex categoryIndex = d->proxyModel->index(block.firstIndex.row(), d->proxyModel->sortColumn(), rootIndex());
-        QStyleOptionViewItemV4 option(viewOptions());
-        option.features |= d->alternatingBlockColors && block.alternate ? QStyleOptionViewItemV4::Alternate
-                           : QStyleOptionViewItemV4::None;
+        QStyleOptionViewItem option(viewOptions());
+        option.features |= d->alternatingBlockColors && block.alternate ? QStyleOptionViewItem::Alternate
+                           : QStyleOptionViewItem::None;
         option.state |= !d->collapsibleBlocks || !block.collapsed ? QStyle::State_Open
                         : QStyle::State_None;
         const int height = d->categoryDrawer->categoryHeight(categoryIndex, option);
@@ -846,13 +846,13 @@ void KCategorizedView::paintEvent(QPaintEvent *event)
 
             const QModelIndex index = d->proxyModel->index(i, modelColumn(), rootIndex());
             const Qt::ItemFlags flags = d->proxyModel->flags(index);
-            QStyleOptionViewItemV4 option(viewOptions());
+            QStyleOptionViewItem option(viewOptions());
             option.rect = visualRect(index);
             option.widget = this;
-            option.features |= wordWrap() ? QStyleOptionViewItemV2::WrapText
-                               : QStyleOptionViewItemV2::None;
-            option.features |= alternatingRowColors() && alternateItem ? QStyleOptionViewItemV4::Alternate
-                               : QStyleOptionViewItemV4::None;
+            option.features |= wordWrap() ? QStyleOptionViewItem::WrapText
+                               : QStyleOptionViewItem::None;
+            option.features |= alternatingRowColors() && alternateItem ? QStyleOptionViewItem::Alternate
+                               : QStyleOptionViewItem::None;
             if (flags & Qt::ItemIsSelectable) {
                 option.state |= selectionModel()->isSelected(index) ? QStyle::State_Selected
                                 : QStyle::State_None;
@@ -959,7 +959,7 @@ void KCategorizedView::mouseMoveEvent(QMouseEvent *event)
     while (it != d->blocks.constEnd()) {
         const Private::Block &block = *it;
         const QModelIndex categoryIndex = d->proxyModel->index(block.firstIndex.row(), d->proxyModel->sortColumn(), rootIndex());
-        QStyleOptionViewItemV4 option(viewOptions());
+        QStyleOptionViewItem option(viewOptions());
         const int height = d->categoryDrawer->categoryHeight(categoryIndex, option);
         QPoint pos = d->blockPosition(it.key());
         pos.ry() -= height;
@@ -971,7 +971,7 @@ void KCategorizedView::mouseMoveEvent(QMouseEvent *event)
         if (option.rect.contains(mousePos)) {
             if (d->hoveredBlock->height != -1 && *d->hoveredBlock != block) {
                 const QModelIndex categoryIndex = d->proxyModel->index(d->hoveredBlock->firstIndex.row(), d->proxyModel->sortColumn(), rootIndex());
-                const QStyleOptionViewItemV4 option = d->blockRect(categoryIndex);
+                const QStyleOptionViewItem option = d->blockRect(categoryIndex);
                 d->categoryDrawer->mouseLeft(categoryIndex, option.rect);
                 *d->hoveredBlock = block;
                 d->hoveredCategory = it.key();
@@ -989,7 +989,7 @@ void KCategorizedView::mouseMoveEvent(QMouseEvent *event)
     }
     if (d->hoveredBlock->height != -1) {
         const QModelIndex categoryIndex = d->proxyModel->index(d->hoveredBlock->firstIndex.row(), d->proxyModel->sortColumn(), rootIndex());
-        const QStyleOptionViewItemV4 option = d->blockRect(categoryIndex);
+        const QStyleOptionViewItem option = d->blockRect(categoryIndex);
         d->categoryDrawer->mouseLeft(categoryIndex, option.rect);
         *d->hoveredBlock = Private::Block();
         d->hoveredCategory = QString();
@@ -1012,7 +1012,7 @@ void KCategorizedView::mousePressEvent(QMouseEvent *event)
     while (it != d->blocks.constEnd()) {
         const Private::Block &block = *it;
         const QModelIndex categoryIndex = d->proxyModel->index(block.firstIndex.row(), d->proxyModel->sortColumn(), rootIndex());
-        const QStyleOptionViewItemV4 option = d->blockRect(categoryIndex);
+        const QStyleOptionViewItem option = d->blockRect(categoryIndex);
         const QPoint mousePos = viewport()->mapFromGlobal(QCursor::pos());
         if (option.rect.contains(mousePos)) {
             d->categoryDrawer->mouseButtonPressed(categoryIndex, option.rect, event);
@@ -1039,7 +1039,7 @@ void KCategorizedView::mouseReleaseEvent(QMouseEvent *event)
     while (it != d->blocks.constEnd()) {
         const Private::Block &block = *it;
         const QModelIndex categoryIndex = d->proxyModel->index(block.firstIndex.row(), d->proxyModel->sortColumn(), rootIndex());
-        const QStyleOptionViewItemV4 option = d->blockRect(categoryIndex);
+        const QStyleOptionViewItem option = d->blockRect(categoryIndex);
         const QPoint mousePos = viewport()->mapFromGlobal(QCursor::pos());
         if (option.rect.contains(mousePos)) {
             d->categoryDrawer->mouseButtonReleased(categoryIndex, option.rect, event);
@@ -1063,7 +1063,7 @@ void KCategorizedView::leaveEvent(QEvent *event)
     }
     if (d->categoryDrawer && d->hoveredBlock->height != -1) {
         const QModelIndex categoryIndex = d->proxyModel->index(d->hoveredBlock->firstIndex.row(), d->proxyModel->sortColumn(), rootIndex());
-        const QStyleOptionViewItemV4 option = d->blockRect(categoryIndex);
+        const QStyleOptionViewItem option = d->blockRect(categoryIndex);
         d->categoryDrawer->mouseLeft(categoryIndex, option.rect);
         *d->hoveredBlock = Private::Block();
         d->hoveredCategory = QString();
@@ -1102,7 +1102,7 @@ void KCategorizedView::dropEvent(QDropEvent *event)
 QModelIndex KCategorizedView::moveCursor(CursorAction cursorAction,
         Qt::KeyboardModifiers modifiers)
 {
-    if (!d->isCategorized()) {
+    if (!d->isCategorized() || viewMode() == QListView::ListMode) {
         return QListView::moveCursor(cursorAction, modifiers);
     }
 
